@@ -69,6 +69,8 @@ ThreadListView::ThreadListView( QWidget* parent, const char* name )
              SLOT( slotSearchButton() ) );
     connect( SearchCombo, SIGNAL( activated( int ) ),
              SLOT( slotSearchButton() ) );
+    connect( SearchCombo, SIGNAL( textChanged( const QString& ) ),
+             SLOT( slotSearchButton() ) );
     connect( HideButton, SIGNAL( toggled( bool ) ),
              SLOT( slotHideButton( bool ) ) );
     connect( subjectList, SIGNAL( mouseButtonClicked( int, QListViewItem*, const QPoint&, int ) ),
@@ -90,7 +92,15 @@ void ThreadListView::slotSearchButton()
 {
     insertSearchCombo();
     QStringList list = parseSearchQuery( SearchCombo->currentText() );
-    searchNext( list );
+
+    if ( list.isEmpty() ) {
+        clearSearch();    
+    } else if ( list != m_prevquery ) {
+        searchNew( list );
+        slotHideButton( true );
+    } else {
+        searchNext( list );
+    }
 }
 
 void ThreadListView::insertSearchCombo()
@@ -118,29 +128,21 @@ QStringList ThreadListView::parseSearchQuery( const QString &input )
 
 void ThreadListView::searchNext( const QStringList &query )
 {
-    if ( query.isEmpty() ) return ;
-
-    if ( query != m_prevquery ) {
-        searchAll( query );
-        slotHideButton( HideButton->isOn() );
-        m_nextHitIndex = 0; //A next jump-search target reset to '0'.
-        return ;
-    }
-
-    if ( m_nextHitIndex >= m_hitList.size() ) {
-        return ;
-    }
+    Q_ASSERT( query == m_prevquery );
+    Q_ASSERT( m_nextHitIndex < m_hitList.size() );
 
     KListViewItem* item = m_hitList[ m_nextHitIndex ];
     subjectList->ensureItemVisible( item );
     subjectList->setSelected( item, true );
+    
     m_nextHitIndex++;
     if ( m_nextHitIndex >= m_hitList.size() ) m_nextHitIndex = 0;
 }
 
-void ThreadListView::searchAll( const QStringList &query )
+void ThreadListView::searchNew( const QStringList &query )
 {
     m_hitList.clear();
+    m_nextHitIndex = 0;
     m_prevquery = query;
 
     QListViewItemIterator listIt( subjectList );
@@ -160,10 +162,19 @@ void ThreadListView::searchAll( const QStringList &query )
     }
 }
 
+void ThreadListView::clearSearch()
+{
+    QListViewItemIterator listIt( subjectList );
+    while ( listIt.current() != 0 ) {
+        KListViewItem * item = static_cast<KListViewItem *>( listIt.current() );
+        item->setPixmap( Col_Icon, 0 );
+        item->setVisible( true );
+        ++listIt;
+    }
+}
+
 void ThreadListView::slotHideButton( bool on )
 {
-    if ( m_hitList.empty() ) return ;
-
     QListViewItemIterator listIt( subjectList );
     while ( listIt.current() != 0 ) {
         KListViewItem * item = static_cast<KListViewItem *>( listIt.current() );
