@@ -633,24 +633,27 @@ void BoardManager::clearBoardData()
     m_previousBoardURL = QString::null;
 }
 
-/* enroll board        */
-
-/* Input: board, boardName, type, test
-   Output: oldURL
- 
-   return: 
-   If board is already enrolled, return Board_enrollEnrolled and oldURL is QString::null.
-   If board is new board, return Board_enrollNew and oldURL is QString::null.
-   If board is moved, return Board_enrollMoved, and oldURL is old URL.
- 
-   Note that board is NOT enrolled when board is moved.
-   To enroll new URL, call BoardManager::moveBoard(). 
- 
-   "int type" is type of board. It could be "Kita::Board_Unknown". See also parseBoardURL().
-   
-   If "bool test" is TRUE, this function just checks if the board is enrolled (never enroll board).
- 
-*/ 
+/**
+ *
+ * @param[in] board
+ * @param[in] boardName
+ * @param[in] type
+ * @param[in] test
+ *
+ * @param[out] oldURL
+ *
+ * @retval Board_enrollEnrolled if board is already enrolled. oldURL is QString::null.
+ * @retval Board_enrollNew if board is new board. oldURL is QString::null.
+ * @retval Board_enrollMoved if board is moved. oldURL is old URL.
+ *
+ * @note board is NOT enrolled when board is moved.
+ * To enroll new URL, call BoardManager::moveBoard(). 
+ *
+ * "int type" is type of board. It could be "Kita::Board_Unknown". See also parseBoardURL().
+ * 
+ * If "bool test" is TRUE, this function just checks if the board is enrolled (never enroll board).
+ *
+ */ 
 /* public */ /* static */
 int BoardManager::enrollBoard( const KURL& url, const QString& boardName, QString& oldURL, int type, bool test )
 {
